import { FieldValidator, FormApi } from 'final-form';
import { FieldProps, FieldRenderProps } from 'react-final-form';
import { ButtonProps } from '@material-ui/core/Button';
interface StandardInputProps<ExtraTexts = {}> {
    name: string;
    fieldProps?: Omit<FieldProps<string, FieldRenderProps<string>>, 'name' | 'validate'>;
    texts?: {
        helperText?: string;
    } & ExtraTexts;
    validate?: FieldValidator<unknown>;
    disabled?: boolean;
}
interface RequiredFileHandlers {
    downloadFile: DownloadFileHandler;
}
interface FileInfoHandler {
    getFileInfo: GetFileInfo;
}
interface DownloadButtonBaseProps extends RequiredFileHandlers, FileInfoHandler {
    value: FileValue;
    fieldName: string;
    errorText?: string;
    helperText?: string;
    documentButtonText: string;
    validate?: FieldValidator<unknown>;
    onOpenClick: ButtonProps['onClick'];
    fileName: string;
    signedDocPath: string;
}
declare enum ButtonType {
    Main = 0,
    Secondary = 1
}
interface FileValue {
    fileName: string;
    uploadDate: Date;
    [key: string]: any;
}
declare type DownloadFileHandler = (fileName: string, url: string) => void;
declare type GetFileInfo = (args: {
    file: FileValue;
    buttonType: ButtonType;
    fieldName: string;
    formApi: FormApi;
}) => {
    fileName: string;
    url: string;
};
interface FileDisplayProps {
    fileName: string;
    uploadDate: Date;
    documentButtonText: string;
    onDownloadClick: ButtonProps['onClick'];
    onOpenClick: ButtonProps['onClick'];
    uploadUrl?: string;
}
export { FileValue, DownloadFileHandler, ButtonType, GetFileInfo, DownloadButtonBaseProps, StandardInputProps, FileDisplayProps };
