import React, { useState } from 'react';
import Button from '@material-ui/core/Button';
import { Loading } from './Loading';
import { Grid } from '@material-ui/core';
import { withStyles, Styles } from './styles';
import { useForm } from 'react-final-form';
import { ButtonLoadingBaseProps } from './types';

export const ButtonLoadingBase = ({
  onClick,
  classes,
  texts
}: ButtonLoadingBaseProps & Styles): JSX.Element => {
  const formApi = useForm();
  const [loading, setLoading] = useState(false);
  const handleClick = async () => {
    setLoading(true);
    await onClick(formApi);
    setLoading(false);
  };

  return (
    <Grid className={classes.container} alignItems="center" direction="column">
      <Button
        color="primary"
        disabled={loading}
        className={classes.button}
        variant="extendedFab"
        onClick={handleClick}
      >
        {texts.buttonText}
      </Button>
      {loading && <Loading loadingText={texts.loadingText} />}
    </Grid>
  );
};

const ButtonLoading = withStyles(ButtonLoadingBase);
export { ButtonLoading };
