import React, { useEffect } from 'react';
import { FormApi, getIn } from 'final-form';
import { faCheckCircle } from '@fortawesome/pro-regular-svg-icons/faCheckCircle';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import Button from '@material-ui/core/Button';
import Typography from '@material-ui/core/Typography';
import { withFinalFormField } from '@comparaonline/ui-with-final-form-field';
import { IFieldProps } from '@comparaonline/ui-wizard-step-manager';
import { Card } from '../Card';
import { withStyles, WithStyles } from './styles';
import cx from 'classnames';
import { FieldNames } from '../../constants';

export interface CardActionProps extends Pick<IFieldProps, 'onClick' | 'formApi'> {
  buttonText: string;
  helperText: string;
  labelSuccessUpload: string;
  labelSuccessDigital: string;
  showIcon: boolean;
  onRender?: (formApi: FormApi) => void;
  value: string;
  isSignedDigital: boolean;
}

const CardActionBase = ({
  buttonText,
  classes,
  formApi,
  helperText,
  labelSuccessUpload,
  labelSuccessDigital,
  onClick,
  onRender,
  showIcon,
  isSignedDigital
}: WithStyles<CardActionProps>): JSX.Element => {
  useEffect(() => {
    if (onRender) onRender(formApi);
  }, []);
  return (
    <Card>
      {!isSignedDigital && (
        <Typography className={classes.label} variant="body1">
          {showIcon && <FontAwesomeIcon className={classes.icon} icon={faCheckCircle} />}
          {labelSuccessUpload}
        </Typography>
      )}
      {isSignedDigital && (
        <Typography className={cx(classes.label, classes.success)} variant="body1">
          {showIcon && <FontAwesomeIcon className={classes.icon} icon={faCheckCircle} />}
          {labelSuccessDigital}
        </Typography>
      )}
      <Typography className={classes.helperText} variant="body2">
        {helperText}
      </Typography>
      <Button className={classes.button} onClick={onClick}>
        {buttonText}
      </Button>
    </Card>
  );
};

const CardAction = withStyles(withFinalFormField(CardActionBase));

export const CardActionField = ({ texts, pathUploadUrl, ...props }): JSX.Element => {
  const { values } = props.formApi.getState();
  const value = getIn(values, pathUploadUrl);
  const isSignedDigital =
    getIn(values, `${FieldNames.Files.PromissoryNote}.digitallySigned`) || false;

  return <CardAction {...props} {...texts} value={value} isSignedDigital={isSignedDigital} />;
};
