import React from 'react';
import AuthCode from 'react-auth-code-input';
import { Grid } from '@material-ui/core';
import { HelperText } from './HelperText';
import { withStyles, Styles } from './styles';
import { useForm } from 'react-final-form';
import { FieldNames, StatusDigitalSignature } from '../../constants';
import { CodeInputProps } from './types';
import { getIn } from 'final-form';

const ERROR_STATUS = [StatusDigitalSignature.Expired, StatusDigitalSignature.Failed];

const CodeInputBase = ({ classes, codeInputs = 4, texts, ...props }: CodeInputProps & Styles) => {
  const formApi = useForm();
  const { values } = formApi.getState();

  const status = getIn(values, FieldNames.IdentityValidation.Status);
  const hasError = ERROR_STATUS.includes(status);

  const handleChange = value => {
    formApi.batch(() => {
      formApi.change(FieldNames.IdentityValidation.Code, value);
      formApi.change(
        FieldNames.IdentityValidation.Status,
        StatusDigitalSignature.WaitingCodeVerification
      );
    });
  };

  let className = '';
  if (status === StatusDigitalSignature.Successful) className = classes.successCode;
  if (hasError) className = classes.errorCode;

  return (
    <Grid container={true} alignItems="center" direction="column">
      <AuthCode
        {...props}
        containerClassName={classes.container}
        onChange={handleChange}
        length={codeInputs}
        inputClassName={`${classes.input} ${className}`}
      />
      {hasError && <HelperText>{texts.errorMessage}</HelperText>}
    </Grid>
  );
};

export const CodeInput = withStyles(CodeInputBase);
