import React, { useState, useEffect, useRef } from 'react';
import { getIn } from 'final-form';
import { useForm } from 'react-final-form';
import Typography from '@material-ui/core/Typography';
import { CloudinaryImage } from '@comparaonline/cloudinary-image';
import { getDistanceFromNow, padStart } from './helpers';
import { withStyles, Styles } from './styles';
import { CountdownProps } from './types';
import { SECOND_AS_MILISECOND, StatusDigitalSignature, FieldNames } from '../../constants';

const CLOCK_ICON = 'v1662394882/assets/checkout/clock.svg';

const CountdownBase = ({ classes, name }: CountdownProps & Styles) => {
  const formApi = useForm();
  const intervalCountdown = useRef<number | NodeJS.Timeout>();
  const expirationDate = getIn(formApi.getState().values, name);
  const [countdownTime, setCountdownTime] = useState(new Date(expirationDate).getTime());
  const [{ minutes, seconds }, setState] = useState(getDistanceFromNow(countdownTime));

  const setNewTime = time => {
    const timeUpdated = getDistanceFromNow(time);
    if (time) setState(getDistanceFromNow(time));
    if (!timeUpdated.minutes && !timeUpdated.seconds) {
      formApi.change(
        FieldNames.IdentityValidation.Status,
        StatusDigitalSignature.VerificationCodeExpired
      );
      clearInterval(intervalCountdown.current as number);
    }
  };

  useEffect(() => {
    setCountdownTime(new Date(expirationDate).getTime());
  }, [expirationDate]);

  useEffect(() => {
    intervalCountdown.current = setInterval(() => setNewTime(countdownTime), SECOND_AS_MILISECOND);
    return () => clearInterval(intervalCountdown.current as number);
  }, [countdownTime]);
  return (
    <>
      <Typography className={classes.text}>
        <CloudinaryImage name={CLOCK_ICON} className={classes.icon} />
        <span>{`${padStart(minutes)}:${padStart(seconds)}`}</span>
      </Typography>
    </>
  );
};

export const Countdown = withStyles(CountdownBase);
