import React, { FC, useCallback, useState } from 'react';
import { useStepManager } from '@comparaonline/ui-wizard-step-manager';
import { useForm } from 'react-final-form';
import { getIn } from 'final-form';
import { StepIds } from '../../constants';
import { DownloadButton, StandardInputProps } from '../DownloadButton';
import { PdfModal } from '../PdfModal';
import { DigitalSignatureProps } from './types';

const DigitalSignature: FC<DigitalSignatureProps> = ({
  name,
  downloadFile,
  getFileInfo,
  signedDocPath,
  texts,
  nameSufix = '.downloadUrl'
}) => {
  const [showDialog, setShowDialog] = useState<boolean>(false);
  const closeDialog = useCallback(() => setShowDialog(false), []);
  const openDialog = useCallback(() => setShowDialog(true), []);

  const formApi = useForm();
  const values = formApi.getState().values;
  const documentUrl = getIn(values, `${name}${nameSufix}`);

  const stepManagerApi = useStepManager();
  const onSecondaryAction = () => {
    stepManagerApi.navigationApi.goTo(StepIds.Insured);
  };

  return (
    <>
      <DownloadButton
        name={name}
        fileName={texts.fileName}
        documentButtonText={texts.documentButtonText}
        downloadFile={downloadFile}
        getFileInfo={getFileInfo}
        onOpenClick={openDialog}
        texts={texts as StandardInputProps['texts']}
        signedDocPath={signedDocPath || `${name}.uploadUrl`}
      />
      <PdfModal
        open={showDialog}
        pdfURL={documentUrl}
        onClose={closeDialog}
        texts={texts}
        onSecondaryAction={onSecondaryAction}
      />
    </>
  );
};

export { DigitalSignature };
