import React, { FC } from 'react';
import { StyleRules, withStyles, withTheme, WithTheme } from '@material-ui/core/styles';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faBan, faCheck } from '@fortawesome/pro-solid-svg-icons';
import Grid from '@material-ui/core/Grid';
import { useForm } from 'react-final-form';
import { getIn } from 'final-form';
import { FieldNames } from '../constants';
import Typography from '@material-ui/core/Typography';

const styles: StyleRules = { body1: { color: 'rgba(0, 0, 0, 0.6)', marginLeft: '8px' } };
const StyledTypography = withStyles(styles)(Typography);

const ValidationResultItem = (props: { resultDetail: string }) => (
  <span>
    {props.resultDetail}
    <br />
  </span>
);

const DocumentValidationResult: FC<WithTheme> = ({ theme }) => {
  const formApi = useForm();
  const values = formApi.getState().values;
  const documentsValidationResult = getIn(values, FieldNames.DocumentsValidationResult.Result);
  const documentsValidationResultDescription: string | string[] = getIn(
    values,
    FieldNames.DocumentsValidationResult.Description
  );
  const isSuccess = documentsValidationResult === 'success';

  return (
    <Grid container={true} justify="center" alignItems="center">
      {isSuccess ? (
        <FontAwesomeIcon icon={faCheck} color={theme.palette.primary.main} />
      ) : (
        <FontAwesomeIcon icon={faBan} color={theme.palette.error.main} />
      )}
      <StyledTypography
        variant="body1"
        inline={true}
        style={isSuccess ? {} : { color: theme.palette.error.main }}
      >
        {typeof documentsValidationResultDescription === 'string'
          ? documentsValidationResultDescription
          : Object.values(documentsValidationResultDescription).map(descriptionItem => (
              <ValidationResultItem key={descriptionItem} resultDetail={descriptionItem} />
            ))}
      </StyledTypography>
    </Grid>
  );
};

const WithThemeDocumentValidationResult = withTheme()(DocumentValidationResult);

export { WithThemeDocumentValidationResult as DocumentValidationResult };
