import React, { FC } from 'react';
import { withTheme, WithTheme } from '@material-ui/core/styles';
import { useFormatMessage } from '@comparaonline/react-intl-hooks';
import CircularProgress from '@material-ui/core/CircularProgress';
import Grid from '@material-ui/core/Grid';
import Typography from '@material-ui/core/Typography';
import { withStyles, StyleRules } from '@material-ui/core/styles';
import { faCheck, faBan } from '@fortawesome/pro-solid-svg-icons';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

const styles: StyleRules = { body1: { color: 'rgba(0, 0, 0, 0.6)', marginLeft: '8px' } };
const StyledTypography = withStyles(styles)(Typography);

interface DocumentStatusProps extends WithTheme {
  isDocumentReady: boolean;
  fieldName: string;
  textData?: Record<string, string>;
  hasDocumentFailed?: boolean;
}

const DocumentStatus: FC<DocumentStatusProps> = ({
  isDocumentReady,
  theme,
  fieldName,
  hasDocumentFailed,
  textData
}) => {
  const t = useFormatMessage();
  const fieldState = isDocumentReady ? 'ready' : 'waiting';
  const hasFailed = hasDocumentFailed && !isDocumentReady;
  const text = t(`files.${fieldName}.${fieldState}`, textData);
  const failedText = t(`files.${fieldName}.error`, textData);
  const textColor = hasFailed ? { color: theme.palette.error.main } : {};
  return (
    <Grid container={true} justify="center" alignItems="center">
      {isDocumentReady ? (
        <FontAwesomeIcon icon={faCheck} color={theme.palette.primary.main} />
      ) : (
        <>{!hasFailed && <CircularProgress size="20px" />}</>
      )}
      {hasFailed && <FontAwesomeIcon icon={faBan} color={theme.palette.error.main} />}
      <StyledTypography variant="body1" inline={true} style={textColor}>
        {hasFailed ? failedText : text}
      </StyledTypography>
    </Grid>
  );
};

const WithThemeDocumentStatus = withTheme()(DocumentStatus);

export { WithThemeDocumentStatus as DocumentStatus };
