import { FormControl, FormHelperText } from '@material-ui/core';
import { getIn } from 'final-form';
import React, { FC } from 'react';
import { useField, useForm } from 'react-final-form';
import { FileDisplay } from './FileDisplay';
import { createDownloadHandler } from './helpers';
import { WithDownloadButtonStyles, withDownloadButtonStyles } from './styles';
import { ButtonType, DownloadButtonBaseProps } from './types';
import { hasContent, hasError } from './utils';

const DownloadButtonBase: FC<DownloadButtonBaseProps & WithDownloadButtonStyles> = ({
  classes,
  value,
  fieldName,
  fileName,
  onOpenClick,
  downloadFile,
  getFileInfo,
  validate,
  helperText,
  documentButtonText,
  signedDocPath
}) => {
  const formApi = useForm();

  const onDownloadClick = createDownloadHandler(
    value,
    ButtonType.Main,
    fieldName,
    getFileInfo,
    downloadFile,
    formApi
  );

  const { meta } = useField(fieldName, {
    validate,
    subscription: { touched: true, error: true, data: true }
  });
  const values = formApi.getState().values;

  const documentUrl = getIn(values, signedDocPath);
  const documentDate = getIn(values, `${fieldName}.uploadDate`);

  return (
    <FormControl classes={{ root: classes.container }} error={hasError(meta)}>
      <FileDisplay
        fileName={value.fileName || fileName}
        uploadDate={documentDate}
        onDownloadClick={onDownloadClick}
        onOpenClick={onOpenClick}
        uploadUrl={documentUrl}
        documentButtonText={documentButtonText}
      />
      {hasContent(helperText) && documentUrl && (
        <FormHelperText className={classes.helperText}>{helperText}</FormHelperText>
      )}
    </FormControl>
  );
};

const StyledDownloadButton = withDownloadButtonStyles(DownloadButtonBase);

export { StyledDownloadButton as DownloadButton };
