import React, { FC } from 'react';
import cx from 'classnames';
import Grid from '@material-ui/core/Grid';
import Button, { ButtonProps } from '@material-ui/core/Button';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faFileAlt } from '@fortawesome/pro-regular-svg-icons/faFileAlt';
import { faDownload } from '@fortawesome/pro-solid-svg-icons/faDownload';
import Typography from '@material-ui/core/Typography';
import { FormattedDate } from 'react-intl';

import { withFileDisplayStyles, WithFileDisplayStyles } from './styles';
import { FileDisplayProps } from './types';

const WithButton = (extraProps: ButtonProps): FC => props => (
  <Button {...props} color="primary" {...extraProps} />
);

const FileDisplay: FC<FileDisplayProps & WithFileDisplayStyles> = ({
  classes,
  fileName,
  uploadDate,
  onDownloadClick,
  onOpenClick,
  documentButtonText,
  uploadUrl
}) => {
  const containerClass = classes.container;
  return (
    <Grid
      container={true}
      wrap="nowrap"
      className={cx(containerClass, { [classes.greenBorder]: true })}
    >
      <Grid container={true} justify="center" alignItems="center" xs={3}>
        <FontAwesomeIcon className={classes.fileIcon} icon={faFileAlt as any} />
      </Grid>
      <Grid container={true} direction="column" justify="center" alignItems="flex-start" xs={7}>
        <Typography variant="body1" className={classes.fileName}>
          {fileName}
        </Typography>
        <Typography variant="body2" className={classes.date}>
          {uploadDate && (
            <FormattedDate value={uploadDate} year="numeric" month="long" day="2-digit" />
          )}
        </Typography>
      </Grid>
      {uploadUrl ? (
        <Grid
          component={WithButton({ onClick: onDownloadClick })}
          container={true}
          justify="center"
          alignItems="center"
          xs={5}
          className={classes.leftGrid}
        >
          <FontAwesomeIcon className={classes.downloadIcon} icon={faDownload as any} />
        </Grid>
      ) : (
        <Grid
          component={WithButton({ onClick: onOpenClick })}
          container={true}
          justify="center"
          alignItems="center"
          xs={5}
          className={classes.leftGrid}
        >
          <span className={classes.labelButton}>{documentButtonText}</span>
        </Grid>
      )}
    </Grid>
  );
};

const StyledFileDisplay = withFileDisplayStyles(FileDisplay);

export { StyledFileDisplay as FileDisplay };
