import React, { FC } from 'react';
import { withFinalFormField, RequiredProps } from '@comparaonline/ui-with-final-form-field';

import { DownloadButton } from './DownloadButton';
import { DownloadButtonBaseProps, FileValue } from './types';
import { StandardInputProps } from './types';

type DownloadButtonBasePropsCleaned = Pick<
  DownloadButtonBaseProps,
  Exclude<keyof DownloadButtonBaseProps, 'value' | 'fieldName'>
>;

type WithFinalFormDownloadButtonBaseProps = DownloadButtonBasePropsCleaned &
  RequiredProps<FileValue>;

const WithFinalFormDownloadButtonBase: FC<WithFinalFormDownloadButtonBaseProps> = ({
  fieldRenderProps: { input },
  ...props
}) => {
  const { value, name } = input;
  return <DownloadButton {...props} value={value} fieldName={name} />;
};

const WithFinalFormDownloadButton = withFinalFormField(WithFinalFormDownloadButtonBase);

type NormalizedDownloadButtonBaseProps = DownloadButtonBasePropsCleaned & StandardInputProps;

const NormalizedDownloadButtonBase: FC<NormalizedDownloadButtonBaseProps> = ({
  texts,
  name,
  fieldProps,
  ...props
}) => {
  return <WithFinalFormDownloadButton {...props} {...texts} fieldProps={{ ...fieldProps, name }} />;
};

export {
  NormalizedDownloadButtonBase as DownloadButton,
  NormalizedDownloadButtonBaseProps as DownloadButtonProps
};
