import React from 'react';
import NumberFormat, { NumberFormatProps } from 'react-number-format';

interface MoneyFormatProps
  extends Pick<
    NumberFormatProps,
    Exclude<keyof NumberFormatProps, 'getInputRef' | 'onValueChange'>
  > {
  inputRef?: NumberFormatProps['getInputRef'];
  onChange?: NumberFormatProps['onValueChange'];
}

export const MoneyFormat: React.FC<MoneyFormatProps> = ({ inputRef, onChange, ...props }) => {
  const onValueChange = values => onChange && onChange(values.value);
  return (
    <NumberFormat
      {...props}
      getInputRef={inputRef ? inputRef : () => undefined}
      onValueChange={onValueChange}
      thousandSeparator="."
      decimalSeparator=","
      prefix="$"
      defaultValue={''}
    />
  );
};
