import React from 'react';
import { withStyles, WithStyles } from './styles';
import { Card } from '../Card';
import Typography from '@material-ui/core/Typography';
import { useFormatMessage } from '@comparaonline/react-intl-hooks';
import { FormApi } from 'final-form';
import { getOrderNumber, isVirtualMode } from '../../helpers';

interface NumberInspectionOrderBaseProps {
  formApi: FormApi;
}

const NumberInspectionOrderBase = ({
  formApi,
  classes
}: WithStyles<NumberInspectionOrderBaseProps>): JSX.Element => {
  const t = useFormatMessage();

  return (
    <Card>
      <Typography className={classes.spaceBetweenText} align="center" variant="body2">
        {t('inspection.order.success.label')}
      </Typography>
      <Typography className={classes.spaceBetweenText} align="center" variant="h4">
        <b>{getOrderNumber(formApi)}</b>
      </Typography>
      <Typography align="center" className={classes.textColor} variant="body2">
        {isVirtualMode(formApi)
          ? t('inspection.order.virtual.helper')
          : t('inspection.order.presential.helper')}
      </Typography>
    </Card>
  );
};

export const NumberInspectionOrder = withStyles(NumberInspectionOrderBase);
