import React from 'react';
import { Styles, withStyles } from './styles';
import Dialog from '@material-ui/core/Dialog';
import DialogContent from '@material-ui/core/DialogContent';
import DialogTitle from '@material-ui/core/DialogTitle';
import { Button, Typography } from '@material-ui/core';
import { faTimes } from '@fortawesome/pro-regular-svg-icons/faTimes';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { PdfModalBaseProps } from './types';
import withMobileDialog, { InjectedProps } from '@material-ui/core/withMobileDialog';

const PdfModalBase = ({
  classes,
  texts,
  onClose,
  onSecondaryAction,
  fullScreen,
  pdfURL,
  open
}: PdfModalBaseProps & InjectedProps & Styles) => {
  const pdfURLWithToolbar = `${pdfURL}#view=FitH`;
  return (
    <Dialog
      open={open}
      maxWidth="lg"
      onClose={onClose}
      fullWidth={true}
      classes={{ paper: classes.dialogPaper, container: classes.container }}
      fullScreen={fullScreen}
    >
      <DialogTitle disableTypography={true} className={classes.dialogTitleContainer}>
        <Typography variant="h6" className={classes.dialogTitleText}>
          {texts.title}
        </Typography>
        <FontAwesomeIcon onClick={onClose} size="lg" icon={faTimes} color="#666666" />
      </DialogTitle>
      <DialogContent>
        <Typography color="textSecondary" variant="body1">
          {texts.subtitle}
        </Typography>
        <iframe src={pdfURLWithToolbar} className={classes.containerPdf} />
        <Button
          onClick={onSecondaryAction}
          className={classes.buttonEdit}
          variant="text"
          color="primary"
        >
          {texts.buttonEdit}
        </Button>
      </DialogContent>
    </Dialog>
  );
};

const MobilePdfModal = withMobileDialog<PdfModalBaseProps & Styles>({ breakpoint: 'xs' })(
  PdfModalBase
);
export const PdfModal = withStyles(MobilePdfModal);
