import React, { useEffect, useState } from 'react';
import { useForm } from 'react-final-form';
import Button from '@material-ui/core/Button';
import Grid from '@material-ui/core/Grid';
import Typography from '@material-ui/core/Typography';
import { isLastResendCode, getResendedCode } from '../../helpers';
import { withStyles } from './styles';

const ResendVerificationCodeBase = ({ classes, onClick, texts }) => {
  const formApi = useForm();
  const [working, setWorking] = useState(false);
  const [isLastResend, setLastResend] = useState(isLastResendCode(formApi));
  const resendCodeFormValue = getResendedCode(formApi);

  const onClickHandler = async () => {
    if (!working) {
      setWorking(true);
      await onClick(formApi);
      setWorking(false);
    }
  };

  useEffect(() => {
    if (!isLastResend && isLastResendCode(formApi)) setLastResend(true);
  }, [resendCodeFormValue]);

  return (
    <Grid className={classes.container} alignItems="center" direction="column" container={true}>
      <Typography variant="body1" className={classes.text}>
        {texts.label}
      </Typography>
      <Button onClick={onClickHandler} disabled={working} className={classes.button}>
        {texts.buttonText}
      </Button>
      {isLastResend && (
        <Typography variant="caption" className={classes.helperText}>
          {texts.helperText}
        </Typography>
      )}
    </Grid>
  );
};

export const ResendVerificationCode = withStyles(ResendVerificationCodeBase);
