import React, { useCallback, useState } from 'react';
import Button from '@material-ui/core/Button';
import Grid from '@material-ui/core/Grid';

import { IFieldProps as FieldProps } from '@comparaonline/ui-wizard-step-manager';

import { NoFieldNames } from '../../constants';
import { WizardModal } from '../WizardModal';
import { Styles, withStyles } from './styles';

interface VirtualInspectionProps extends Pick<FieldProps, 'texts'> {}

const steps = [
  {
    image: 'v1632149363/assets/checkout/paso1_desktop_hqsqna.png',
    text: `${NoFieldNames.Inspection.VirtualInspectionModal}.text.step1`
  },
  {
    image: 'v1632149363/assets/checkout/paso2_desktop_e3ura2.png',
    text: `${NoFieldNames.Inspection.VirtualInspectionModal}.text.step2`
  },
  {
    image: 'v1632149363/assets/checkout/paso3_desktop_gz4gkd.png',
    text: `${NoFieldNames.Inspection.VirtualInspectionModal}.text.step3`
  }
];

const VirtualInspectionBase: React.FC<VirtualInspectionProps & Styles> = ({
  classes,
  texts: { label }
}) => {
  const [showDialog, setShowDialog] = useState<boolean>(false);
  const closeDialog = useCallback(() => setShowDialog(false), []);
  const openDialog = useCallback(() => setShowDialog(true), []);

  return (
    <Grid container={true} justify="center">
      <Button variant="extendedFab" onClick={openDialog} className={classes.button}>
        {label}
      </Button>
      <WizardModal open={showDialog} steps={steps} onClose={closeDialog} />
    </Grid>
  );
};

export const VirtualInspection = withStyles(VirtualInspectionBase);
