import {
  WithStyles as MUIWithStyles,
  StyleRulesCallback,
  withStyles as withStylesCb
} from '@material-ui/core/styles';

const styles: StyleRulesCallback = theme => {
  const {
    breakpoints,
    palette: { primary },
    spacing: { unit }
  } = theme;

  const button = {
    boxShadow: 'none',
    flex: '1 1 auto',
    margin: `0 ${unit}px`,
    '&:disabled': {
      display: 'none'
    },
    maxWidth: '38%',
    [breakpoints.down('sm')]: {
      maxWidth: '100%'
    }
  };

  return {
    back: {
      ...button,
      background: 'white',
      border: `1px solid ${primary.main}`,
      color: primary.main
    },
    closeButton: {
      position: 'absolute',
      right: unit,
      top: unit
    },
    closeIcon: {
      color: 'rgba(0, 0, 0, 0.6)',
      height: 14,
      width: 14
    },
    dot: {
      borderRadius: 4,
      height: 8,
      width: 8
    },
    dotActive: {
      width: 16
    },
    dots: {
      flex: '100%',
      justifyContent: 'center',
      order: -1,
      marginBottom: unit * 2
    },
    image: {
      maxWidth: '100%',
      width: 877
    },
    next: {
      ...button
    },
    paper: {
      borderRadius: `${unit * 2}px ${unit * 2}px 0 0`,
      maxWidth: 877
    },
    stepper: {
      backgroundColor: 'transparent',
      flexWrap: 'wrap',
      justifyContent: 'center',
      padding: `0 ${unit * 10}px ${unit * 4}px`,
      [breakpoints.down('sm')]: {
        padding: `0 ${unit * 4}px ${unit * 4}px`
      }
    },
    text: {
      padding: `${unit * 2}px ${unit * 6}px`,
      textAlign: 'center'
    }
  };
};

type Styles = MUIWithStyles<typeof styles>;
const withStyles = withStylesCb(styles);

export { withStyles, Styles };
