import { CicoAutomasInspectionType } from '@comparaonline/inspection-scheduler-schema';
import { InspectionType } from '../../constants/InspectionType';
import { getInspectionType, getInspectionTypeDefaultValue } from '../getInspectionType';

describe('getInspectionType helpers', () => {
  describe('getInspectionType', () => {
    it.each([
      // expect AVA and/or CEN
      ['automas', [CicoAutomasInspectionType.AVA, CicoAutomasInspectionType.CEN]],
      ['virtual,centro', [CicoAutomasInspectionType.AVA, CicoAutomasInspectionType.CEN]],
      ['centro,virtual', [CicoAutomasInspectionType.CEN, CicoAutomasInspectionType.AVA]],
      ['foo,virtual,centro,bar', [CicoAutomasInspectionType.AVA, CicoAutomasInspectionType.CEN]],
      ['virtual', [CicoAutomasInspectionType.AVA]],
      ['centro', [CicoAutomasInspectionType.CEN]],
      // expect OWN
      ['', [InspectionType.Own]],
      ['own', [InspectionType.Own]],
      ['foo,bar', [InspectionType.Own]],
      ['virtual.centro', [InspectionType.Own]],
      ['virtualcentro', [InspectionType.Own]],
    ])('Offer with "%s" should show the inspection %s', (inspectionType, expected) => {
      const product = getMockedProduct(inspectionType);
      expect(getInspectionType(product)).toEqual(expected);
    });
  });

  describe('getInspectionTypeDefaultValue', () => {
    it.each([
      // expect AVA
      ['automas', CicoAutomasInspectionType.AVA],
      ['virtual,centro', CicoAutomasInspectionType.AVA],
      ['centro,virtual', CicoAutomasInspectionType.AVA],
      ['foo,virtual,centro,bar', CicoAutomasInspectionType.AVA],
      ['virtual', CicoAutomasInspectionType.AVA],
      ['', CicoAutomasInspectionType.AVA],
      ['own', CicoAutomasInspectionType.AVA],
      ['foo,bar', CicoAutomasInspectionType.AVA],
      ['virtual.centro', CicoAutomasInspectionType.AVA],
      ['virtualcentro', CicoAutomasInspectionType.AVA],
      // expect CEN
      ['centro', CicoAutomasInspectionType.CEN],
    ])('Offer with "%s" should set inspection as %s initially', (inspectionType, expected) => {
      const product = getMockedProduct(inspectionType);
      expect(getInspectionTypeDefaultValue(product)).toEqual(expected);
    });
  });
});

function getMockedProduct(inspectionType: string): any {
  return {
    productAttributes: [
      {
        entity: {
          code: 'inspection-type'
        },
        value: inspectionType
      }
    ]
  };
}
