import { Deserializer } from 'ts-jsonapi';
import { FailedResponse } from './types';

const deserializer = new Deserializer({
  keyForAttribute: 'camelCase',
  pluralizeType: false
});

const headers = {
  accept: 'application/vnd.api+json',
  'Content-Type': 'application/vnd.api+json'
};

export const fetchBFF = async <Response = unknown>(
  endpoint: string,
  requestData: unknown,
  method: string = 'POST'
): Promise<Response> => {
  const body = JSON.stringify({
    data: {
      attributes: requestData,
      type: 'identity-validation'
    }
  });

  const response = await fetch(`${endpoint}`, {
    body,
    headers,
    method
  });

  if (!response.ok) throw response;

  const data = await response.json();
  const deserializedResponse = deserializer.deserialize(data);

  if ('errorCode' in deserializedResponse) throw deserializedResponse as FailedResponse;
  return deserializedResponse as Response;
};
