import { FormApi } from 'final-form';
import { StepIds } from '../../constants';
import { Question } from '../../types';

export type BypassCodeValidationResponse = {
  expirationDate: string;
  identityValidationId: number;
  status: string;
  questions: Question[];
};

export type FailedResponse = {
  errorCode: string;
  message: string;
  status: string;
};

export type InitIdentityValidationCodeResponse = BypassCodeValidationResponse | SendCodeResponse;

export type SendCodeResponse = {
  expirationDate: string;
  identityValidationId: number;
  status: string;
};

export type SignedDocument = {
  fileName: string;
  downloadUrl: string;
};

export type VerifyAndSignResponse = {
  identityValidationId: number;
  signedDocuments: SignedDocument[];
  status: string;
};

type DigitalSignatureServiceMethodOkResponse<SuccessfulData> = DigitalSignatureServiceMethod<
  | (SuccessfulData & {
      ok: true;
    })
  | { ok: false }
>;

export type BypassCodeValidation = DigitalSignatureServiceMethodOkResponse<{
  questions: Question[];
}>;

export type InitIdentityValidation = DigitalSignatureServiceMethodOkResponse<{
  step: StepIds;
  questions?: Question[];
}>;

export type DigitalSignatureServiceMethod<Response> = (
  formApi: FormApi,
  BFFURL: string
) => Promise<Response>;

export type VerifyAndSignMethod = (
  formApi: FormApi,
  BFFURL: string,
  sarlaftSignatureRequired: boolean,
  additionalDocumentName?: string
) => Promise<boolean>;
