import { FinalFormPaser } from '@comparaonline/ui-wizard-step-manager/dist/types';
import { getCardType } from './creditCard';

type Parser = FinalFormPaser<string, string>;

const cleanStringByRegExp = (value: string, regExp: RegExp, separator: string = ''): string => {
  const matches = String(value).match(regExp);
  return matches ? matches.join(separator) : '';
};

export const noLetters: Parser = value => cleanStringByRegExp(value, /[^a-zA-Z]*/g);

export const noNumbers: Parser = value => cleanStringByRegExp(value, /[^\d]*/g);

export const onlyLetters: Parser = value => cleanStringByRegExp(value, /\[a-zA-Z]*/g);

export const onlyNumbers: Parser = value => cleanStringByRegExp(value, /\d*/g);

export const creditCard: Parser = value => {
  const cleanedValue = value.replace(/\D/g, '');
  const cardType = getCardType(cleanedValue);
  return cardType ? cardType.group(cleanedValue).join(' ') : value;
};

export const thousand: Parser = (value, name) =>
  onlyNumbers(value, name).replace(/\B(?=(\d{3})+(?!\d))/g, '.');
