import { CicoAutomasInspectionType } from '@comparaonline/inspection-scheduler-schema';
import { InspectionType } from '../constants/InspectionType';
import { Offer } from '../types';

const ONE_TYPE = 1;
const CODE_INSPECTION_TYPE = 'inspection-type';
const NEW_INSPECTION_TYPES_SEPARATOR = ',';

const MATCH_INSPECTION_TYPES_NAME = {
  centro: CicoAutomasInspectionType.CEN,
  virtual: CicoAutomasInspectionType.AVA
};

export const getInspectionType = (product: Offer['product']): string[] => {
  const productAttributeValue = product.productAttributes.find(
    attr => attr.entity.code === CODE_INSPECTION_TYPE
  )?.value as string;

  return parseInspectionType((productAttributeValue || '').toLowerCase());
};

export const getInspectionTypeDefaultValue = (
  product: Offer['product']
): CicoAutomasInspectionType => {
  const allowedInspectionTypes: string[] = getInspectionType(product);

  if (
    allowedInspectionTypes.length === ONE_TYPE &&
    allowedInspectionTypes.includes(CicoAutomasInspectionType.CEN)
  )
    return CicoAutomasInspectionType.CEN;

  return CicoAutomasInspectionType.AVA;
};

function parseInspectionType(inspectionType?: string): string[] {
  if (!inspectionType || inspectionType === InspectionType.Own) return [InspectionType.Own];

  if (inspectionType === InspectionType.Automas)
    return [CicoAutomasInspectionType.AVA, CicoAutomasInspectionType.CEN];

  const inspectionTypes = inspectionType
    .split(NEW_INSPECTION_TYPES_SEPARATOR)
    .map(oldInspectionName => MATCH_INSPECTION_TYPES_NAME[oldInspectionName])
    .filter(Boolean);

  return inspectionTypes.length ? inspectionTypes : [InspectionType.Own];
}
