import { ApolloClient } from 'apollo-client';
import { FormApi } from 'final-form';
import { FieldNames, optionOther } from '../constants';
import { getFieldStateValue } from './getFieldStateValue';
import { getFinancialEntities } from './getFinancialEntities';
import { getBanks, getCarColors, getColombiaCities, getCountries } from '../queries';
import { injectOptionOther } from './injectOptionOther';
import { Bank, SarlaftPersonType } from '../types';

const sarlaftPersonTypes = Object.keys(SarlaftPersonType);
const isOptionOther = value => value && value.value === optionOther.value;

const handleFormLoad = (client: ApolloClient<any>, bffURL: string) => (formApi: FormApi) => {
  getCarColors().then(colors => {
    const colorOptions = colors.map(({ name, id }) => ({
      label: name,
      value: id
    }));

    formApi.mutators.setFieldData(FieldNames.Insured.Car.Color, {
      options: colorOptions
    });
  });

  getColombiaCities().then(cities => {
    const cityOptions = cities.map(({ id, name }) => ({
      label: name,
      value: id
    }));

    sarlaftPersonTypes.forEach(sarlaftPersonType => {
      const { Person, Work } = FieldNames[sarlaftPersonType];
      const BirthplaceValue = getFieldStateValue(formApi, Person.Birthplace);
      const isOther = isOptionOther(BirthplaceValue);

      formApi.mutators.setFieldData(Work.CompanyCity, {
        options: cityOptions
      });

      formApi.mutators.setFieldData(Person.City, {
        options: cityOptions
      });

      formApi.mutators.setFieldData(Person.PlaceIssued, {
        options: injectOptionOther(cityOptions)
      });

      formApi.mutators.setFieldData(Person.Birthplace, {
        options: injectOptionOther(cityOptions),
        loading: isOther
      });
    });
  });

  getCountries().then(countries => {
    const countryOptions = countries.map(({ code, name_es: name }) => ({
      label: name,
      value: code
    }));

    sarlaftPersonTypes.forEach(sarlaftPersonType => {
      formApi.mutators.setFieldData(FieldNames[sarlaftPersonType].Person.Nationality, {
        options: countryOptions
      });

      formApi.mutators.setFieldData(
        FieldNames[sarlaftPersonType].PublicResources.PublicLinkNationality,
        {
          options: countryOptions
        }
      );

      formApi.mutators.setFieldData(
        FieldNames[sarlaftPersonType].ForeignTaxation.FinancialProductCountry,
        {
          options: countryOptions
        }
      );
    });
  });

  getFinancialEntities(client).then(financialEntities => {
    const options = financialEntities.map((entity: any) => ({
      label: entity.name,
      value: entity.id,
      ...entity
    }));
    formApi.mutators.setFieldData(FieldNames.Insured.FinancialEntity, {
      options
    });
  });

  getBanks(bffURL).then((banks: Bank[] | void) => {
    if (!banks || !banks.length) return;

    const options = banks.map(({ id, name }) => ({
      label: name,
      value: id
    }));

    formApi.mutators.setFieldData(FieldNames.Payment.PSE.Bank, { options });
  });
};

export { handleFormLoad };
