import { FormApi } from 'final-form';
import { CicoAutomasInspectionType } from '@comparaonline/inspection-scheduler-schema';
import { FieldNames } from '../constants';
import { AllowedInspectionType } from '../types';
import { getFieldStateValue } from './getFieldStateValue';

export const isVirtualMode = (formApi: FormApi) =>
  CicoAutomasInspectionType.AVA === getFieldStateValue(formApi, FieldNames.Inspection.Type);

export const hasOrderNumber = (formApi: FormApi): boolean =>
  !!getFieldStateValue(formApi, FieldNames.Inspection.Number);

export const getOrderNumber = (formApi: FormApi) =>
  getFieldStateValue(formApi, FieldNames.Inspection.Number);

export const isCreateOrderWithPresential = (formApi: FormApi) => {
  const type = getFieldStateValue(formApi, FieldNames.Inspection.OrderCreatedWithType);
  const numberOrder = getFieldStateValue(formApi, FieldNames.Inspection.Number);
  return type === CicoAutomasInspectionType.CEN && numberOrder;
};

export const hasErrorInspectionOrder = (formApi: FormApi): boolean => {
  const errorInspection = getFieldStateValue(formApi, FieldNames.FieldsNoSave.ErrorInspectionOrder);
  return !!errorInspection;
};

export const showForVirtualMode = (
  formApi: FormApi,
  allowedInspectionTypes: AllowedInspectionType
): boolean =>
  isVirtualMode(formApi) && allowedInspectionTypes.includes(CicoAutomasInspectionType.AVA);
