import { FormApi } from 'final-form';
import { CicoSarlaftType } from '@comparaonline/cico-funnel-schema';
import { FieldNames } from '../constants';
import { BooleanValues, SarlaftPersonType } from '../types';
import { getFieldStateValue } from '../helpers';

const LAST_FIELD_BY_SARLAFT_TYPE: Record<CicoSarlaftType, string> = {
  [CicoSarlaftType.LONG]: 'HasClaims',
  [CicoSarlaftType.SHORT]: 'PrincipalSourceOfIncome'
};

type LastFieldValue = boolean | string | undefined;

const getLastSarlaftValue = (
  sarlaftType: CicoSarlaftType,
  sarlaftPersonType: SarlaftPersonType,
  formApi: FormApi
): LastFieldValue =>
  getFieldStateValue(
    formApi,
    FieldNames[sarlaftPersonType][LAST_FIELD_BY_SARLAFT_TYPE[sarlaftType]]
  );

const validateLastField = (value: LastFieldValue, sarlaftType: CicoSarlaftType): boolean =>
  sarlaftType === CicoSarlaftType.SHORT
    ? Boolean(value)
    : value === BooleanValues.No || value === BooleanValues.Yes;

export const isValidSarlaft = (sarlaftPersonType: SarlaftPersonType, formApi: FormApi): boolean => {
  const {
    errors: { sarlaft: sarlaftErrors = {} },
    values: {
      sarlaft: {
        insured: { type: sarlaftType = CicoSarlaftType.LONG }
      }
    }
  } = formApi.getState();

  const lastFieldSarlaftValue = getLastSarlaftValue(sarlaftType, sarlaftPersonType, formApi);
  const isValidLastField: boolean = validateLastField(lastFieldSarlaftValue, sarlaftType);

  return Boolean(isValidLastField && !sarlaftErrors[sarlaftPersonType.toLowerCase()]);
};
