import { AnyObject, FormApi } from 'final-form';
import deepmerge from 'deepmerge';
import { getCiiuCode } from './getCiiuCode';

const mergeNames = (valueA: any, valueB: any) => {
  if (Array.isArray(valueA)) {
    return [...valueA, ...valueB];
  }
  return valueB;
};

const mergeOptions = {
  customMerge: () => mergeNames
};

export const onValuesUpdate = (formApi: FormApi, firestoreData: AnyObject) => {
  const { values } = formApi.getState();
  let mergedValues = deepmerge(values, firestoreData, mergeOptions);
  const { ciiuCode, occupationType } = mergedValues?.sarlaft?.insured?.work || {};

  if (occupationType && !ciiuCode) {
    mergedValues = deepmerge(mergedValues, {
      sarlaft: {
        insured: {
          work: {
            ciiuCode: getCiiuCode(occupationType)
          }
        }
      }
    });
  }

  formApi.initialize(() => mergedValues);
};
