import { Checkout, CheckoutFiles } from '@comparaonline/cico-funnel-schema';
import { DeepPartial, Offer } from '../types';
import { transformInput } from '../helpers';
import { FieldNames } from '../constants';
import { getInspectionType, getInspectionTypeDefaultValue } from './getInspectionType';

const otherDocumentsName = FieldNames.Files.OtherDocuments.split('.');
const isOtherDocuments = fieldName =>
  fieldName === otherDocumentsName[otherDocumentsName.length - 1];
const toFileValueArray = obj =>
  Object.keys(obj).map(attr => ({
    ...obj[attr],
    uploadDate: obj[attr].uploadDate.toDate()
  }));

const getDates = (files: DeepPartial<CheckoutFiles> = {}): DeepPartial<CheckoutFiles> => {
  const filesCopied = { ...files };
  return Object.keys(filesCopied).reduce((prev, curr) => {
    let file = filesCopied[curr];

    if (isOtherDocuments(curr)) {
      file = toFileValueArray(file);
    } else {
      file = { ...file, uploadDate: file.uploadDate && file.uploadDate.toDate() };
    }

    return {
      ...prev,
      [curr]: file
    };
  }, {});
};

const parseRequestedForm = (values: DeepPartial<Checkout>, offer: Offer): DeepPartial<Checkout> => {
  const transformedValues = transformInput(values);
  const currentInspectionType = transformedValues.inspection?.type;
  const allowedInspectionTypes: string[] = getInspectionType(offer.product);

  const inspectionType = allowedInspectionTypes.includes(currentInspectionType as string)
    ? currentInspectionType
    : getInspectionTypeDefaultValue(offer.product);

  return {
    ...transformedValues,
    inspection: {
      ...transformedValues.inspection,
      type: inspectionType
    },
    files: getDates(values.files)
  };
};

export { parseRequestedForm };
