import { CheckoutFilesDetail, CicoPaymentMethod } from '@comparaonline/cico-funnel-schema';
import { FormApi, getIn } from 'final-form';
import { FieldNames } from '../constants';
import { isPaymentMethod } from './payment';
import { StatusPromissoryNote } from '../constants/promissoryNote';

export const getPromissoryNote = async (formApi: FormApi) => {
  formApi.change(FieldNames.PromissoryNote.Status, StatusPromissoryNote.Failed);
};

export const getPromissoryNoteRetries = (formApi: FormApi): number => {
  const { values } = formApi.getState();
  return getIn(values, FieldNames.PromissoryNote.Retries) || 0;
};

export const getPromissoryNoteStatus = (formApi: FormApi) => {
  const { values } = formApi.getState();
  return getIn(values, FieldNames.PromissoryNote.Status);
};

const getUrlsPromissoryNote = (formApi: FormApi): Partial<CheckoutFilesDetail> => {
  const { values } = formApi.getState();
  return getIn(values, FieldNames.Files.PromissoryNote);
};

export const hasPromissoryNote = (formApi: FormApi) => {
  const promissoryNote = getUrlsPromissoryNote(formApi);
  return Boolean(promissoryNote?.downloadUrl);
};

export const hasFailedPromissoryNote = (formApi: FormApi): boolean => {
  const promissoryNoteStatus = getPromissoryNoteStatus(formApi);
  const hasPromissoryNoteRetries = getPromissoryNoteRetries(formApi) !== 0;
  return promissoryNoteStatus === StatusPromissoryNote.Failed && hasPromissoryNoteRetries;
};

export const displayDigitalSignatureForPromissoryNote = (formApi: FormApi): boolean => {
  return isPaymentMethod(formApi, CicoPaymentMethod.Financed) && hasPromissoryNote(formApi);
};

export const displayManualUploadForPromissoryNote = (formApi: FormApi): boolean => {
  return (
    isPaymentMethod(formApi, CicoPaymentMethod.Financed) &&
    (hasPromissoryNote(formApi) || hasFailedPromissoryNote(formApi))
  );
};
