import { Checkout, Entity } from '@comparaonline/cico-funnel-schema';
import { OptionItem } from '@comparaonline/ui-form-fields-next';
import { getIn, setIn } from 'final-form';

import { FieldNames } from '../constants';
import { DeepPartial, SarlaftPersonType, Transformer } from '../types';

const sarlaftPersonTypes: SarlaftPersonType[] = [
  SarlaftPersonType.Insured,
  SarlaftPersonType.Payer
];

const getSarlaftFieldNamesReducer = (accum: string[], sarlaftPersonType: string) => {
  const sarlaft = FieldNames[sarlaftPersonType];

  return accum.concat([
    sarlaft.ForeignTaxation.FinancialProductCountry,
    sarlaft.PublicResources.PublicLinkNationality,
    sarlaft.Person.Birthplace,
    sarlaft.Person.City,
    sarlaft.Person.Nationality,
    sarlaft.Person.PlaceIssued,
    sarlaft.Work.CiiuCode,
    sarlaft.Work.CompanyCity
  ]);
};

const EntitiesNames: string[] = [
  FieldNames.Insured.Car.Color,
  ...sarlaftPersonTypes.reduce(getSarlaftFieldNamesReducer, [])
];

type OptionItemToEntity = (optionItem: OptionItem) => Entity;

const optionItemToEntity: OptionItemToEntity = ({ label, value }) => ({
  id: value,
  name: label
});

type EntityToOptionItem = (entity: Entity) => OptionItem;

const entityToOptionItem: EntityToOptionItem = ({ id, name }) => ({
  label: name,
  value: id
});

type TransformData = (
  values: DeepPartial<Checkout>,
  transform: OptionItemToEntity | EntityToOptionItem
) => DeepPartial<Checkout>;

const transformData: TransformData = (values, transform) => {
  let data = { ...values };
  EntitiesNames.forEach((name: string): void => {
    const value = getIn(data, name);

    if (value && (value.id || value.value)) {
      data = setIn(data, name, transform(value));
    }
  });

  return data;
};

const transformInput: Transformer = values => transformData(values, entityToOptionItem);
const transformOutput: Transformer = values => transformData(values, optionItemToEntity);

export { transformInput, transformOutput };
