import { getIn, setIn } from 'final-form';
import { FieldNames } from '../constants';
import { Transformer } from '../types';

const FINANCIAL_PATH = FieldNames.Insured.FinancialEntity;

const renameFinancialFields = (values, keysMatch) => {
  let data = { ...values };
  const financialValue = getIn(data, FINANCIAL_PATH);

  if (financialValue) {
    const financial = Object.keys(financialValue).reduce((output, key) => {
      const newKey = keysMatch[key] || key;
      output[newKey] = financialValue[key];
      return output;
    }, {});

    data = setIn(data, FINANCIAL_PATH, financial);
  }
  return data;
};

const transformInput: Transformer = values =>
  renameFinancialFields(values, { id: 'value', name: 'label' });

const transformOutput: Transformer = values =>
  renameFinancialFields(values, { value: 'id', label: 'name' });

export { transformInput, transformOutput };
