import { getIn, setIn } from 'final-form';
import { FieldNames } from '../constants';
import { SarlaftPersonType, Transformer } from '../types';

const sarlaftPersonTypes: SarlaftPersonType[] = [
  SarlaftPersonType.Insured,
  SarlaftPersonType.Payer
];

const getSarlaftFieldNamesReducer = (accum: string[], sarlaftPersonType: string) => {
  const sarlaft = FieldNames[sarlaftPersonType];

  return accum.concat([
    sarlaft.ForeignTaxation.HasFinancialProducts,
    sarlaft.ForeignTaxation.HasForeignCurrencyOperations,
    sarlaft.PublicResources.HasPublicLink,
    sarlaft.PublicResources.HasPublicPosition,
    sarlaft.PublicResources.IsPubliclyRecognized,
    sarlaft.PublicResources.ManagePublicResources,
    sarlaft.HasClaims,
    sarlaft.IsCarFinanced,
    sarlaft.IsOwner,
    sarlaft.IsOwnerThePayer
  ]);
};

const FIELDS: string[] = sarlaftPersonTypes.reduce(getSarlaftFieldNamesReducer, []);

export const transformInput: Transformer = values => {
  let data = { ...values };

  FIELDS.forEach((fieldname: string): void => {
    const value = getIn(data, fieldname);
    if (typeof value !== 'undefined' && value !== null) {
      data = setIn(data, fieldname, !!value);
    }
  });

  return data;
};
