import { Bank } from '../types';

interface JSONAPIBank {
  type: 'banks';
  id: string;
  attributes: {
    description: string;
    pseCode: string;
  };
}

interface Response {
  data: JSONAPIBank[];
}

const headers = {
  accept: 'application/vnd.api+json',
  'Content-Type': 'application/vnd.api+json'
};

export const getBanks = (bffURL: string): Promise<Bank[] | void> =>
  fetch(`${bffURL}/payments/banks`, { headers })
    .then(response => {
      if (response.ok) {
        return response.json();
      }
    })
    .then(
      (response?: Response) =>
        response &&
        response.data.map((jsonApiBank: JSONAPIBank) => ({
          id: jsonApiBank.attributes.pseCode,
          name: jsonApiBank.attributes.description
        }))
    );
