import { AutoCompleteTextFieldFilled, TextFieldFilled } from '@comparaonline/ui-form-fields-next';
import { validateWith } from '@comparaonline/ui-forms-validators/dist/validateWith';
import {
  FieldNames,
  CarSectionId,
  MAX_CAR_CHASSIS_LENGTH,
  MAX_CAR_CYLINDER_CAPACITY_LENGTH,
  MAX_CAR_MOTOR_NUMBER_LENGTH,
  MAX_CAR_SERIE_LENGTH,
  StepIds,
  StepNames
} from '../constants';
import * as validators from '../validators';
import { SectionProps, Step } from '@comparaonline/ui-wizard-step-manager/dist/types';
import { fieldIsRequired } from '../helpers';

const carSection: SectionProps = {
  id: CarSectionId,
  name: () => StepNames.Car
};

export const getCarSteps = (optionalSarlaftFields?: string[]): Step[] => {
  return [
    {
      section: carSection,
      id: StepIds.Car,
      next: StepIds.Files,
      title: t => t(`${CarSectionId}.title`),
      subtitle: t => t('sarlaft.Insured'),
      subtitlePlacement: 'top',
      fields: [
        {
          component: TextFieldFilled,
          muiInputProps: {
            InputProps: {
              inputProps: {
                maxLength: MAX_CAR_MOTOR_NUMBER_LENGTH
              }
            }
          },
          name: FieldNames.Insured.Car.Engine,
          showLabel: true,
          texts: {
            label: t => t(`${FieldNames.Insured.Car.Engine}.label`)
          },
          validate:
            fieldIsRequired(FieldNames.Insured.Car.Engine, optionalSarlaftFields) &&
            validateWith(validators.required)
        },
        {
          component: TextFieldFilled,
          muiInputProps: {
            InputProps: {
              inputProps: {
                maxLength: MAX_CAR_CHASSIS_LENGTH
              }
            }
          },
          name: FieldNames.Insured.Car.Chassis,
          showLabel: true,
          texts: {
            label: t => t(`${FieldNames.Insured.Car.Chassis}.label`)
          },
          validate:
            fieldIsRequired(FieldNames.Insured.Car.Chassis, optionalSarlaftFields) &&
            validateWith(validators.required)
        },
        {
          component: TextFieldFilled,
          muiInputProps: {
            InputProps: {
              inputProps: {
                maxLength: MAX_CAR_SERIE_LENGTH
              }
            }
          },

          name: FieldNames.Insured.Car.Serial,
          showLabel: true,
          texts: {
            label: t => t(`${FieldNames.Insured.Car.Serial}.label`)
          },
          validate:
            fieldIsRequired(FieldNames.Insured.Car.Serial, optionalSarlaftFields) &&
            validateWith(validators.required)
        },
        {
          component: TextFieldFilled,
          muiInputProps: {
            InputProps: {
              inputProps: {
                maxLength: MAX_CAR_CYLINDER_CAPACITY_LENGTH,
                type: 'number'
              }
            }
          },
          name: FieldNames.Insured.Car.CylinderCapacity,
          showLabel: true,
          texts: {
            label: t => t(`${FieldNames.Insured.Car.CylinderCapacity}.label`),
            placeholder: t => t(`${FieldNames.Insured.Car.CylinderCapacity}.placeholder`)
          },
          validate:
            fieldIsRequired(FieldNames.Insured.Car.CylinderCapacity, optionalSarlaftFields) &&
            validateWith(validators.required)
        },
        {
          checkForDataOptions: true,
          component: AutoCompleteTextFieldFilled,
          name: FieldNames.Insured.Car.Color,
          showLabel: true,
          texts: {
            label: t => t(`${FieldNames.Insured.Car.Color}.label`),
            placeholder: t => t(`${FieldNames.Insured.Car.Color}.placeholder`)
          },
          validate:
            fieldIsRequired(FieldNames.Insured.Car.Color, optionalSarlaftFields) &&
            validateWith(validators.required)
        }
      ]
    }
  ];
};
