import { FormatMessage } from '@comparaonline/react-intl-hooks';
import { TextFieldFilled } from '@comparaonline/ui-form-fields-next';
import { validateWith } from '@comparaonline/ui-forms-validators/dist/validateWith';
import { AutoCompleteProps, InputModeProps } from '@comparaonline/ui-input-helpers';
import { DateInputMask } from '@comparaonline/ui-text-masks';
import { DATE_FORMAT_REGEXP, FieldNames } from '../../constants';
import { SarlaftPersonType } from '../../types';
import { date, match, required } from '../../validators';
import { fieldIsRequired } from '../../helpers';

const I18N_PREFIX = FieldNames.Insured.Person.DateIssued;

export const getDateIssuedField = (
  sarlaftPersonType: SarlaftPersonType,
  optionalFieldNames?: string[]
) => ({
  component: TextFieldFilled,
  muiInputProps: {
    InputProps: {
      inputProps: {
        ...InputModeProps.numeric,
        ...AutoCompleteProps.birthDay
      },
      inputComponent: DateInputMask
    }
  },
  name: FieldNames[sarlaftPersonType].Person.DateIssued,
  showLabel: true,
  texts: {
    label: (t: FormatMessage) => t(`${I18N_PREFIX}.label`),
    placeholder: (t: FormatMessage) => t(`${I18N_PREFIX}.placeholder`)
  },
  validate:
    fieldIsRequired(FieldNames[sarlaftPersonType].Person.DateIssued, optionalFieldNames) &&
    validateWith(required, match({ regexp: DATE_FORMAT_REGEXP }), date)
});
