import { FormatMessage } from '@comparaonline/react-intl-hooks';
import { TextFieldFilled } from '@comparaonline/ui-form-fields-next';
import { validateWith } from '@comparaonline/ui-forms-validators/dist/validateWith';
import { FieldNames } from '../../constants';
import { SarlaftPersonType } from '../../types';
import { required, email, bypassValidator } from '../../validators';
import { fieldIsRequired } from '../../helpers';

const I18N_PREFIX = FieldNames.Insured.Person.Email;

export const getEmailField = (
  sarlaftPersonType: SarlaftPersonType,
  optionalFieldNames?: string[]
) => ({
  component: TextFieldFilled,
  muiInputProps: {
    InputProps: {
      inputProps: {
        type: 'email'
      }
    }
  },
  name: FieldNames[sarlaftPersonType].Person.Email,
  showLabel: true,
  texts: {
    label: (t: FormatMessage) => t(`${I18N_PREFIX}.label`),
    placeholder: (t: FormatMessage) => t(`${I18N_PREFIX}.placeholder`)
  },
  validate: validateWith(
    fieldIsRequired(FieldNames[sarlaftPersonType].Person.Email, optionalFieldNames)
      ? required
      : bypassValidator,
    email
  )
});
