import { FormatMessage } from '@comparaonline/react-intl-hooks';
import { TextFieldFilled } from '@comparaonline/ui-form-fields-next';
import { validateWith } from '@comparaonline/ui-forms-validators/dist/validateWith';
import { FieldNames, genderOptions } from '../../constants';
import { SarlaftPersonType } from '../../types';
import { requiredWithFalsies } from '../../validators';
import { fieldIsRequired } from '../../helpers';

const I18N_PREFIX = FieldNames.Insured.Person.Gender;

export const getGenderField = (
  sarlaftPersonType: SarlaftPersonType,
  optionalFieldNames?: string[]
) => ({
  component: TextFieldFilled,
  muiInputProps: {
    InputProps: {
      disabled: sarlaftPersonType === SarlaftPersonType.Insured
    }
  },
  name: FieldNames[sarlaftPersonType].Person.Gender,
  options: genderOptions,
  select: true,
  showLabel: true,
  texts: {
    label: (t: FormatMessage) => t(`${I18N_PREFIX}.label`),
    placeholder: (t: FormatMessage) => t(`${I18N_PREFIX}.placeholder`)
  },
  validate:
    fieldIsRequired(FieldNames[sarlaftPersonType].Person.Gender, optionalFieldNames) &&
    validateWith(requiredWithFalsies)
});
