import { FormatMessage } from '@comparaonline/react-intl-hooks';
import { TextFieldFilled } from '@comparaonline/ui-form-fields-next';
import { validateWith } from '@comparaonline/ui-forms-validators/dist/validateWith';
import { FieldNames } from '../../constants';
import { SarlaftPersonType } from '../../types';
import { required } from '../../validators';
import { fieldIsRequired } from '../../helpers';

const I18N_PREFIX = FieldNames.Insured.Person.IdentificationNumber;

export const getIdentificationNumberField = (
  sarlaftPersonType: SarlaftPersonType,
  optionalFieldNames?: string[]
) => ({
  component: TextFieldFilled,
  muiInputProps: {
    InputProps: {
      disabled: sarlaftPersonType === SarlaftPersonType.Insured
    }
  },
  name: FieldNames[sarlaftPersonType].Person.IdentificationNumber,
  showLabel: true,
  texts: {
    label: (t: FormatMessage) => t(`${I18N_PREFIX}.label`),
    placeholder: (t: FormatMessage) => t(`${I18N_PREFIX}.placeholder`)
  },
  validate:
    fieldIsRequired(
      FieldNames[sarlaftPersonType].Person.IdentificationNumber,
      optionalFieldNames
    ) && validateWith(required)
});
