import { FormatMessage } from '@comparaonline/react-intl-hooks';
import { TextFieldFilled } from '@comparaonline/ui-form-fields-next';
import { validateWith } from '@comparaonline/ui-forms-validators/dist/validateWith';
import { ColombiaPhoneInputMask } from '@comparaonline/ui-text-masks';
import { FieldNames } from '../../constants';
import { SarlaftPersonType } from '../../types';
import { bypassValidator, required } from '../../validators';
import { fieldIsRequired } from '../../helpers';
import { landlineAndPhoneValidator } from '../../validators/landlineAndPhoneValidator';

const I18N_PREFIX = FieldNames.Insured.Person.Landline;

export const getLandlineField = (
  sarlaftPersonType: SarlaftPersonType,
  optionalFieldNames?: string[]
) => ({
  component: TextFieldFilled,
  muiInputProps: {
    InputProps: {
      inputComponent: ColombiaPhoneInputMask,
      inputProps: {
        type: 'tel'
      }
    }
  },
  name: FieldNames[sarlaftPersonType].Person.Landline,
  showLabel: true,
  texts: {
    label: (t: FormatMessage) => t(`${I18N_PREFIX}.label`),
    placeholder: (t: FormatMessage) => t(`${I18N_PREFIX}.placeholder`)
  },
  validate: validateWith(
    fieldIsRequired(FieldNames[sarlaftPersonType].Person.Landline, optionalFieldNames)
      ? required
      : bypassValidator,
    landlineAndPhoneValidator
  )
});
