import { FormatMessage } from '@comparaonline/react-intl-hooks';
import { TextFieldFilled } from '@comparaonline/ui-form-fields-next';
import { validateWith } from '@comparaonline/ui-forms-validators/dist/validateWith';
import { FieldNames } from '../../constants';
import { SarlaftPersonType } from '../../types';
import { required } from '../../validators';
import { fieldIsRequired } from '../../helpers';

const I18N_PREFIX = FieldNames.Insured.PrincipalSourceOfIncome;

export const getPrincipalSourceOfIncomeField = (
  sarlaftPersonType: SarlaftPersonType,
  labelI18nKey: string = `${I18N_PREFIX}.label`,
  optionalFieldNames?: string[]
) => ({
  component: TextFieldFilled,
  muiInputProps: {
    multiline: true,
    rows: 3
  },
  name: FieldNames[sarlaftPersonType].PrincipalSourceOfIncome,
  showLabel: true,
  texts: {
    label: (t: FormatMessage) => t(labelI18nKey),
    helperText: (t: FormatMessage) => t(`${I18N_PREFIX}.helperText`),
    placeholder: (t: FormatMessage) => t(`${I18N_PREFIX}.placeholder`)
  },
  validate:
    fieldIsRequired(FieldNames[sarlaftPersonType].PrincipalSourceOfIncome, optionalFieldNames) &&
    validateWith(required)
});
