import {
  AutoCompleteTextFieldFilled,
  CardButtonGroup,
  TextFieldFilled
} from '@comparaonline/ui-form-fields-next';
import { validateWith } from '@comparaonline/ui-forms-validators/dist/validateWith';

import { fieldIsRequired, fieldValueIsTrue } from '../../../helpers';
import * as validators from '../../../validators';
import { FieldNames, booleanOptions, identificationTypeOptions } from '../../../constants';
import { SarlaftPersonType } from '../../../types';

const hasPublicLink = sarlaftPersonType =>
  fieldValueIsTrue(FieldNames[sarlaftPersonType].PublicResources.HasPublicLink);

export const publicLink = (sarlaftPersonType: SarlaftPersonType, optionalFieldNames?: string[]) => [
  {
    component: CardButtonGroup,
    labelPosition: 'center',
    name: FieldNames[sarlaftPersonType].PublicResources.HasPublicLink,
    options: booleanOptions,
    showLabel: true,
    texts: {
      label: t => t(`${FieldNames.Insured.PublicResources.HasPublicLink}.label`),
      labelTooltip: t => t(`${FieldNames.Insured.PublicResources.HasPublicLink}.labelTooltip`)
    },
    validate:
      fieldIsRequired(
        FieldNames[sarlaftPersonType].PublicResources.HasPublicLink,
        optionalFieldNames
      ) && validateWith(validators.requiredWithFalsies)
  },
  {
    component: TextFieldFilled,
    conditionToRender: hasPublicLink(sarlaftPersonType),
    name: FieldNames[sarlaftPersonType].PublicResources.PublicLinkRelation,
    showLabel: true,
    texts: {
      label: t => t(`${FieldNames.Insured.PublicResources.PublicLinkRelation}.label`)
    },
    validate:
      fieldIsRequired(
        FieldNames[sarlaftPersonType].PublicResources.PublicLinkRelation,
        optionalFieldNames
      ) && validateWith(validators.required)
  },
  {
    component: TextFieldFilled,
    conditionToRender: hasPublicLink(sarlaftPersonType),
    name: FieldNames[sarlaftPersonType].PublicResources.PublicLinkName,
    showLabel: true,
    texts: {
      label: t => t(`${FieldNames.Insured.PublicResources.PublicLinkName}.label`)
    },
    validate:
      fieldIsRequired(
        FieldNames[sarlaftPersonType].PublicResources.PublicLinkName,
        optionalFieldNames
      ) && validateWith(validators.required)
  },
  {
    component: TextFieldFilled,
    conditionToRender: hasPublicLink(sarlaftPersonType),
    name: FieldNames[sarlaftPersonType].PublicResources.PublicLinkIdentificationType,
    options: identificationTypeOptions,
    select: true,
    showLabel: true,
    texts: {
      label: t => t(`${FieldNames.Insured.PublicResources.PublicLinkIdentificationType}.label`)
    },
    validate:
      fieldIsRequired(
        FieldNames[sarlaftPersonType].PublicResources.PublicLinkIdentificationType,
        optionalFieldNames
      ) && validateWith(validators.required)
  },
  {
    component: TextFieldFilled,
    conditionToRender: hasPublicLink(sarlaftPersonType),
    name: FieldNames[sarlaftPersonType].PublicResources.PublicLinkIdentificationNumber,
    showLabel: true,
    texts: {
      label: t => t(`${FieldNames.Insured.PublicResources.PublicLinkIdentificationNumber}.label`)
    },
    validate:
      fieldIsRequired(
        FieldNames[sarlaftPersonType].PublicResources.PublicLinkIdentificationNumber,
        optionalFieldNames
      ) && validateWith(validators.required)
  },
  {
    checkForDataOptions: true,
    component: AutoCompleteTextFieldFilled,
    conditionToRender: hasPublicLink(sarlaftPersonType),
    name: FieldNames[sarlaftPersonType].PublicResources.PublicLinkNationality,
    showLabel: true,
    texts: {
      label: t => t(`${FieldNames.Insured.PublicResources.PublicLinkNationality}.label`)
    },
    validate:
      fieldIsRequired(
        FieldNames[sarlaftPersonType].PublicResources.PublicLinkNationality,
        optionalFieldNames
      ) && validateWith(validators.required)
  },
  {
    component: TextFieldFilled,
    conditionToRender: hasPublicLink(sarlaftPersonType),
    name: FieldNames[sarlaftPersonType].PublicResources.PublicLinkPosition,
    showLabel: true,
    texts: {
      label: t => t(`${FieldNames.Insured.PublicResources.PublicLinkPosition}.label`)
    },
    validate:
      fieldIsRequired(
        FieldNames[sarlaftPersonType].PublicResources.PublicLinkPosition,
        optionalFieldNames
      ) && validateWith(validators.required)
  }
];
