import { CardButtonGroup, TextFieldFilled } from '@comparaonline/ui-form-fields-next';
import { validateWith } from '@comparaonline/ui-forms-validators/dist/validateWith';

import { fieldIsRequired, fieldValueIsTrue } from '../../../helpers';
import * as validators from '../../../validators';
import { FieldNames, booleanOptions } from '../../../constants';
import { SarlaftPersonType } from '../../../types';

export const publicPosition = (
  sarlaftPersonType: SarlaftPersonType,
  optionalFieldNames?: string[]
) => [
  {
    component: CardButtonGroup,
    name: FieldNames[sarlaftPersonType].PublicResources.HasPublicPosition,
    options: booleanOptions,
    labelPosition: 'center',
    showLabel: true,
    texts: {
      label: t => t(`${FieldNames.Insured.PublicResources.HasPublicPosition}.label`),
      labelTooltip: t => t(`${FieldNames.Insured.PublicResources.HasPublicPosition}.labelTooltip`)
    },
    validate:
      fieldIsRequired(
        FieldNames[sarlaftPersonType].PublicResources.HasPublicPosition,
        optionalFieldNames
      ) && validateWith(validators.requiredWithFalsies)
  },
  {
    component: TextFieldFilled,
    conditionToRender: fieldValueIsTrue(
      FieldNames[sarlaftPersonType].PublicResources.HasPublicPosition
    ),
    muiInputProps: {
      multiline: true,
      rows: 3
    },
    name: FieldNames[sarlaftPersonType].PublicResources.PublicPosition,
    showLabel: true,
    texts: {
      helperText: t => t(`${FieldNames.Insured.PublicResources.PublicPosition}.helperText`),
      label: t => t(`${FieldNames.Insured.PublicResources.PublicPosition}.label`)
    },
    validate:
      fieldIsRequired(
        FieldNames[sarlaftPersonType].PublicResources.PublicPosition,
        optionalFieldNames
      ) && validateWith(validators.required)
  }
];
