import { CardButtonGroup, TextFieldFilled } from '@comparaonline/ui-form-fields-next';
import { validateWith } from '@comparaonline/ui-forms-validators/dist/validateWith';

import * as validators from '../../../validators';
import { FieldNames, booleanOptions } from '../../../constants';
import { SarlaftPersonType } from '../../../types';
import { fieldIsRequired, fieldValueIsTrue } from '../../../helpers';

export const publicRecognition = (
  sarlaftPersonType: SarlaftPersonType,
  optionalFieldNames?: string[]
) => [
  {
    component: CardButtonGroup,
    labelPosition: 'center',
    name: FieldNames[sarlaftPersonType].PublicResources.IsPubliclyRecognized,
    options: booleanOptions,
    showLabel: true,
    texts: {
      label: t => t(`${FieldNames.Insured.PublicResources.IsPubliclyRecognized}.label`),
      labelTooltip: t =>
        t(`${FieldNames.Insured.PublicResources.IsPubliclyRecognized}.labelTooltip`)
    },
    validate:
      fieldIsRequired(
        FieldNames[sarlaftPersonType].PublicResources.IsPubliclyRecognized,
        optionalFieldNames
      ) && validateWith(validators.requiredWithFalsies)
  },
  {
    component: TextFieldFilled,
    conditionToRender: fieldValueIsTrue(
      FieldNames[sarlaftPersonType].PublicResources.IsPubliclyRecognized
    ),
    muiInputProps: {
      multiline: true,
      rows: 3
    },
    name: FieldNames[sarlaftPersonType].PublicResources.PublicRecognition,
    showLabel: true,
    texts: {
      helperText: t => t(`${FieldNames.Insured.PublicResources.PublicRecognition}.helperText`),
      label: t => t(`${FieldNames.Insured.PublicResources.PublicRecognition}.label`)
    },
    validate:
      fieldIsRequired(
        FieldNames[sarlaftPersonType].PublicResources.PublicRecognition,
        optionalFieldNames
      ) && validateWith(validators.required)
  }
];
