import { CardButtonGroup, TextFieldFilled } from '@comparaonline/ui-form-fields-next';
import { validateWith } from '@comparaonline/ui-forms-validators/dist/validateWith';

import { fieldIsRequired, fieldValueIsTrue } from '../../../helpers';
import * as validators from '../../../validators';
import { FieldNames, booleanOptions } from '../../../constants';
import { SarlaftPersonType } from '../../../types';

export const publicResources = (
  sarlaftPersonType: SarlaftPersonType,
  optionalFieldNames?: string[]
) => [
  {
    name: FieldNames[sarlaftPersonType].PublicResources.ManagePublicResources,
    component: CardButtonGroup,
    options: booleanOptions,
    labelPosition: 'center',
    showLabel: true,
    texts: {
      label: t => t(`${FieldNames.Insured.PublicResources.ManagePublicResources}.label`),
      labelTooltip: t =>
        t(`${FieldNames.Insured.PublicResources.ManagePublicResources}.labelTooltip`)
    },
    validate:
      fieldIsRequired(
        FieldNames[sarlaftPersonType].PublicResources.ManagePublicResources,
        optionalFieldNames
      ) && validateWith(validators.requiredWithFalsies)
  },
  {
    component: TextFieldFilled,
    conditionToRender: fieldValueIsTrue(
      FieldNames[sarlaftPersonType].PublicResources.ManagePublicResources
    ),
    muiInputProps: {
      multiline: true
    },
    name: FieldNames[sarlaftPersonType].PublicResources.PublicResources,
    showLabel: true,
    texts: {
      label: t => t(`${FieldNames.Insured.PublicResources.PublicResources}.label`)
    },
    validate:
      fieldIsRequired(
        FieldNames[sarlaftPersonType].PublicResources.PublicResources,
        optionalFieldNames
      ) && validateWith(validators.required)
  }
];
