import { AutoCompleteTextFieldFilled, CardButtonGroup } from '@comparaonline/ui-form-fields-next';
import { validateWith } from '@comparaonline/ui-forms-validators/dist/validateWith';
import { Error, DividerFieldContainer, Step } from '@comparaonline/ui-wizard-step-manager';

import { SarlaftDialogImage } from '../components';
import { FieldNames, StepIds, StepNames } from '../constants';
import { booleanOptions } from '../constants/options/BooleanOptions';
import {
  createOptionPlaceholders,
  fieldIsRequired,
  fieldValueIsFalse,
  fieldValueIsTrue
} from '../helpers';
import * as validators from '../validators';
import { SectionProps } from '@comparaonline/ui-wizard-step-manager/dist/types';

const sarlaftSection: SectionProps = {
  id: 'sarlaft-section',
  name: () => StepNames.Sarlaft
};

export const getCommonSarlaftSteps = (optionalSarlaftFields?: string[]): Step[] => {
  return [
    {
      section: sarlaftSection,
      id: StepIds.CarOwner,
      title: t => t('relation.title'),
      subtitle: t => t('sarlaft.Insured'),
      subtitlePlacement: 'top',
      disableSubmitButton: fieldValueIsFalse(FieldNames.Insured.IsOwner),
      next: StepIds.Relation,
      dialogProps: {
        bodies: t => [t('sarlaft.dialog.message')],
        submitText: t => t('sarlaft.dialog.button'),
        title: t => t('sarlaft.dialog.title'),
        topAdornment: SarlaftDialogImage
      },
      onStepLoad: ({ dialogState }) => dialogState.setOpenDialog(true),
      secondaryButton: {
        hide: fieldValueIsTrue(FieldNames.Insured.IsOwner),
        onClick: ({ formApi }) => {
          formApi.mutators.redirectToQuote();
        },
        text: t => t('sarlaft.relation.editInfo')
      },
      fields: [
        {
          component: CardButtonGroup,
          name: FieldNames.Insured.IsOwner,
          options: booleanOptions,
          labelPosition: 'center',
          showLabel: true,
          texts: {
            label: t => t(`${FieldNames.Insured.IsOwner}.label`)
          },
          warning: {
            component: Error,
            text: t => t(`${FieldNames.Insured.IsOwner}.warning`),
            when: fieldValueIsFalse(FieldNames.Insured.IsOwner)
          },
          validate:
            fieldIsRequired(FieldNames.Insured.IsOwner, optionalSarlaftFields) &&
            validateWith(validators.requiredWithFalsies)
        }
      ]
    },
    {
      section: sarlaftSection,
      id: StepIds.Relation,
      next: StepIds.Insured,
      title: t => t('relation.title'),
      subtitle: t => t('sarlaft.Insured'),
      subtitlePlacement: 'top',
      fields: [
        {
          component: CardButtonGroup,
          container: DividerFieldContainer,
          name: FieldNames.Insured.IsOwnerThePayer,
          options: booleanOptions,
          labelPosition: 'center',
          showLabel: true,
          texts: {
            label: t => t(`${FieldNames.Insured.IsOwnerThePayer}.label`)
          },
          validate:
            fieldIsRequired(FieldNames.Insured.IsOwnerThePayer, optionalSarlaftFields) &&
            validateWith(validators.requiredWithFalsies),
          warning: {
            text: t => t(`${FieldNames.Insured.IsOwnerThePayer}.warning`),
            when: fieldValueIsFalse(FieldNames.Insured.IsOwnerThePayer)
          }
        },
        {
          component: CardButtonGroup,
          labelPosition: 'center',
          name: FieldNames.Insured.IsCarFinanced,
          options: booleanOptions,
          showLabel: true,
          texts: {
            label: t => t(`${FieldNames.Insured.IsCarFinanced}.label`)
          },
          validate:
            fieldIsRequired(FieldNames.Insured.IsCarFinanced, optionalSarlaftFields) &&
            validateWith(validators.requiredWithFalsies)
        },
        {
          checkForDataOptions: true,
          component: AutoCompleteTextFieldFilled,
          conditionToRender: fieldValueIsTrue(FieldNames.Insured.IsCarFinanced),
          name: FieldNames.Insured.FinancialEntity,
          options: createOptionPlaceholders(9, '90px'),
          showLabel: true,
          texts: {
            label: t => t(`${FieldNames.Insured.FinancialEntity}.label`),
            placeholder: t => t(`${FieldNames.Insured.FinancialEntity}.placeholder`)
          },
          validate:
            fieldIsRequired(FieldNames.Insured.FinancialEntity, optionalSarlaftFields) &&
            validateWith(validators.required)
        }
      ]
    }
  ];
};
