import { Step } from '@comparaonline/ui-wizard-step-manager';

import { StepIds, insuredSection, payerSection } from '../constants';
import { SarlaftPersonType } from '../types';
import { getAddressField } from './fields/address';
import { getBirthdateField } from './fields/birthdate';
import { getCityField } from './fields/city';
import { getDateIssuedField } from './fields/dateIssued';
import { getEmailField } from './fields/email';
import { getFirstNameField } from './fields/firstName';
import { getGenderField } from './fields/gender';
import { getIdentificationNumberField } from './fields/identificationNumber';
import { getIdentificationTypeField } from './fields/identificationType';
import { getLandlineField } from './fields/landline';
import { getLastNameField } from './fields/lastName';
import { getMiddleNameField } from './fields/middleName';
import { getNeighborhoodField } from './fields/neigborhood';
import { getPlaceIssuedField } from './fields/placeIssued';
import { getPhoneField } from './fields/phone';
import { getPrincipalSourceOfIncomeField } from './fields/principalSourceOfIncome';
import { getSecondLastNameField } from './fields/secondLastName';
import { occupationSteps } from './occupationSteps';

export const shortSarlaftSteps = (
  sarlaftPersonType: SarlaftPersonType,
  nextStep: StepIds,
  optionalFieldNames?: string[]
): Step[] => {
  const section = sarlaftPersonType === SarlaftPersonType.Insured ? insuredSection : payerSection;
  const subtitle = t => t(`sarlaft.${sarlaftPersonType}`);
  const title = t => t('insured.title');

  return [
    {
      id: StepIds[`${sarlaftPersonType}`],
      next: StepIds[`${sarlaftPersonType}Address`],
      section,
      subtitlePlacement: 'top',
      subtitle,
      title,
      fields: [
        getFirstNameField(sarlaftPersonType, optionalFieldNames),
        getMiddleNameField(sarlaftPersonType),
        getLastNameField(sarlaftPersonType, optionalFieldNames),
        getSecondLastNameField(sarlaftPersonType),
        getGenderField(sarlaftPersonType, optionalFieldNames),
        getBirthdateField(sarlaftPersonType, optionalFieldNames),
        [
          getIdentificationTypeField(sarlaftPersonType, optionalFieldNames),
          getIdentificationNumberField(sarlaftPersonType, optionalFieldNames)
        ],
        getPlaceIssuedField(sarlaftPersonType, optionalFieldNames),
        getDateIssuedField(sarlaftPersonType, optionalFieldNames)
      ]
    },
    {
      id: StepIds[`${sarlaftPersonType}Address`],
      next: StepIds[`${sarlaftPersonType}OccupationType`],
      section,
      subtitlePlacement: 'top',
      subtitle,
      title,
      fields: [
        getAddressField(sarlaftPersonType, optionalFieldNames),
        getNeighborhoodField(sarlaftPersonType, optionalFieldNames),
        getCityField(sarlaftPersonType, optionalFieldNames),
        getLandlineField(sarlaftPersonType, optionalFieldNames),
        getPhoneField(sarlaftPersonType, optionalFieldNames),
        getEmailField(sarlaftPersonType, optionalFieldNames),
        getPrincipalSourceOfIncomeField(
          sarlaftPersonType,
          'sourceOfIncome.title',
          optionalFieldNames
        )
      ]
    },
    ...occupationSteps({ sarlaftPersonType, nextStep, optionalFieldNames })
  ];
};
