import { FormApi } from 'final-form';
import { FieldSubscription } from '@comparaonline/ui-wizard-form-next';

import { FieldNames } from '../constants';
import { SarlaftPersonType } from '../types';
import { getFieldStateValue } from '../helpers';

const getNumberValue = (formApi: FormApi, fieldName: string): number => {
  const value = getFieldStateValue(formApi, fieldName);
  return Number(value || 0);
};

const createListener = (
  sarlaftPersonType: SarlaftPersonType,
  fieldName: string
): FieldSubscription => ({
  fieldName,
  subscriber: ({ formApi }) => {
    const assets = getNumberValue(formApi, FieldNames[sarlaftPersonType].Work.Assets);
    const liabilities = getNumberValue(formApi, FieldNames[sarlaftPersonType].Work.Liabilities);
    const wealth = assets - liabilities;
    formApi.change(FieldNames[sarlaftPersonType].Work.Wealth, wealth);
  },
  subscriptionOptions: { value: true }
});

export const wealthCalculators = [
  createListener(SarlaftPersonType.Insured, FieldNames.Insured.Work.Assets),
  createListener(SarlaftPersonType.Insured, FieldNames.Insured.Work.Liabilities),
  createListener(SarlaftPersonType.Payer, FieldNames.Payer.Work.Assets),
  createListener(SarlaftPersonType.Payer, FieldNames.Payer.Work.Liabilities)
];
