import { FormApi } from 'final-form';
import { FieldSubscription } from '@comparaonline/ui-wizard-form-next';
import { CompanyTypes, OccupationTypes } from '@comparaonline/common-schema';

import { FieldNames, unemployedValues } from '../constants';
import { SarlaftPersonType } from '../types';
import { getFieldStateValue, isUnemployed, getCiiuCode } from '../helpers';

const subscriber = (
  formApi: FormApi,
  sarlaftPersonType: string,
  occupationType: OccupationTypes
): void => {
  const Person = FieldNames[sarlaftPersonType].Person;
  const Work = FieldNames[sarlaftPersonType].Work;

  const unemployedWorkValues = {
    [Work.Company]: occupationType,
    [Work.CompanyAddress]: getFieldStateValue(formApi, Person.Address),
    [Work.CompanyPhone]: getFieldStateValue(formApi, Person.Phone),
    [Work.CompanyType]: CompanyTypes.Other,
    [Work.Occupation]: occupationType,
    [Work.Position]: occupationType
  };

  const fieldNamesToClean = [Work.Company, Work.Occupation, Work.Position];
  const fieldNamesToChange = [
    Work.CompanyAddress,
    Work.CompanyPhone,
    Work.CompanyType,
    ...fieldNamesToClean
  ];

  formApi.batch(() => {
    formApi.change(Work.CiiuCode, getCiiuCode(occupationType));

    if (isUnemployed(occupationType)) {
      fieldNamesToChange.forEach((fieldName: string): void => {
        formApi.change(fieldName, unemployedWorkValues[fieldName]);
      });
    } else {
      fieldNamesToClean.forEach(fieldName => {
        const value = getFieldStateValue(formApi, fieldName);
        if (unemployedValues.includes(value)) {
          formApi.change(fieldName, undefined);
        }
      });
    }
  });
};

const occupationTypeListener: FieldSubscription[] = Object.keys(SarlaftPersonType).map(
  sarlaftPersonType => ({
    subscriber: ({ formApi, fieldState: { value } }) =>
      subscriber(formApi, sarlaftPersonType, value),
    fieldName: FieldNames[sarlaftPersonType].Work.OccupationType,
    subscriptionOptions: { value: true }
  })
);

export { occupationTypeListener };
