import debounce from 'debounce';
import { FormApi, getIn } from 'final-form';
import { onFormValidDebounce, FieldNames } from '../constants';
import { prepareFirestoreDataHandler } from '../helpers';
import { Submitter } from '../types';

const fieldExceptionList = [
  FieldNames.Files.IdentificationDocument,
  FieldNames.Files.InsuredSarlaft,
  FieldNames.Files.OtherDocuments,
  FieldNames.Files.PayerSarlaft,
  FieldNames.Files.PromissoryNote,
  FieldNames.Files.PropertyCertificate
];

const changesHasError = (formApi: FormApi): boolean => {
  const { errors = {}, modified = {}, values } = formApi.getState();

  const isModified = (fieldName: string): boolean => modified[fieldName];
  const hasError = (fieldName: string): boolean => Boolean(getIn(errors, fieldName));
  const byFieldExceptionList = (fieldName: string) =>
    fieldExceptionList.every(fieldException => fieldException !== fieldName);
  const byExists = (fieldName: string) => {
    const fieldValue = getIn(values, fieldName);
    return fieldValue !== undefined && fieldValue !== null;
  };

  const changesWithError = Object.keys(modified)
    .filter(isModified)
    .filter(hasError)
    .filter(byExists)
    .filter(byFieldExceptionList);

  return Boolean(changesWithError.length);
};

const isFormValid = (formApi: FormApi, callback: Submitter) => {
  const { dirty, validating } = formApi.getState();

  if (!dirty || validating || changesHasError(formApi)) {
    return;
  }

  const { values } = formApi.getState();
  prepareFirestoreDataHandler(callback)(values, formApi);
};

const debouncedIsFormValid = debounce(isFormValid, onFormValidDebounce);

export const onFormValidSubscription = (subscribers: Submitter[]) =>
  subscribers.map(subscriber => ({
    subscriber: (formApi: FormApi) => () => debouncedIsFormValid(formApi, subscriber),
    subscription: { values: true }
  }));
