import { CustomizableValidator } from '@comparaonline/ui-forms-validators/dist/types/Validator';

const LENGTH_MAX_CODE = 'LENGTH_MAX_ERROR';
const LENGTH_MIN_CODE = 'LENGTH_MIN_ERROR';

interface LengthParams {
  max?: number;
  min?: number;
  cleanValue?: (value: string) => string;
}

export const length: CustomizableValidator<LengthParams> = ({ cleanValue, min, max }) => value => {
  if (!value) return undefined;
  const finalValue = cleanValue ? cleanValue(value as string) : (value as string);
  const valueLength = finalValue.length;

  if (max && valueLength > max) return { errorCode: LENGTH_MAX_CODE, params: { max, min } };
  if (min && valueLength < min) return { errorCode: LENGTH_MIN_CODE, params: { max, min } };

  return undefined;
};

export const lengthMaxCode = LENGTH_MAX_CODE;
export const lengthMinCode = LENGTH_MIN_CODE;
